<?php
class Bavotasan_Documentation {
	public function __construct() {
		add_action( 'admin_menu', array( $this, 'admin_menu' ), 1 );
		add_action( 'admin_bar_menu', array( $this, 'admin_bar_menu' ), 1 );
	}

	/**
	 * Add a 'Documentation' menu item to the admin bar
	 *
	 * This function is attached to the 'admin_bar_menu' action hook.
	 *
	 * @param	array $wp_admin_bar
	 *
	 * @since 1.0.0
	 */
	function admin_bar_menu( $wp_admin_bar ) {
	    if ( current_user_can( 'edit_theme_options' ) && is_admin_bar_showing() )
			$wp_admin_bar->add_node( array( 'parent' => 'bavotasan_toolbar', 'id' => 'bavotasan_documentation', 'title' => sprintf( __( 'About %s', 'magazine-premium' ), BAVOTASAN_THEME_NAME ), 'href' => admin_url( 'themes.php?page=bavotasan_documentation' ) ) );
	}

	/**
	 * Add a 'Documentation' menu item to the Appearance panel
	 *
	 * This function is attached to the 'admin_menu' action hook.
	 *
	 * @since 1.0.0
	 */
	public function admin_menu() {
		add_theme_page( sprintf( __( 'Welcome to %1$s %2$s', 'magazine-premium' ), BAVOTASAN_THEME_NAME, BAVOTASAN_THEME_VERSION ), sprintf( __( 'About %s', 'magazine-premium' ), BAVOTASAN_THEME_NAME ), 'edit_theme_options', 'bavotasan_documentation', array( $this, 'bavotasan_documentation' ) );
	}

	public function bavotasan_documentation() {
		?>
		<style>
		.featured-image {
			margin: 20px auto !important;
		}

		.about-wrap .headline-feature h2 {
			text-align: center;
		}

		.about-wrap .dfw h3 {
			text-align: left;
		}

		.changelog.headline-feature.dfw {
			max-width: 68%;
		}

		.changelog.headline-feature.dfw {
			margin-left: auto;
			margin-right: auto;
		}

		.about-wrap ul {
			padding-left: 60px;
			list-style: disc;
			margin-bottom: 20px;
		}

		.about-wrap .theme-badge {
			position: absolute;
			top: 0;
			right: 0;
		}

		.about-wrap .feature-section {
			border: 0;
			padding: 0;
		}

		.videoWrapper {
			position: relative;
			padding-bottom: 56.25%; /* 16:9 */
			padding-top: 25px;
			height: 0;
		}

		.videoWrapper iframe {
			position: absolute;
			top: 0;
			left: 0;
			width: 100%;
			height: 100%;
		}

		@media only screen and (max-width: 768px) {
			.changelog.headline-feature.dfw {
				max-width: 100%;
			}

			.about-wrap .theme-badge {
				display: none;
			}
		}
		</style>
		<div class="wrap about-wrap" id="custom-background">
			<h1><?php echo get_admin_page_title(); ?></h1>

			<div class="about-text">
				<?php printf( __( 'Read through the following documentation to learn more about <em>%1$s</em> and how to use the available theme options. Or %2%scheck out the demo%3$s to see it in action.', 'magazine-premium' ), BAVOTASAN_THEME_NAME, '<a href="//demos.bavotasan.com/' . sanitize_title( BAVOTASAN_THEME_NAME ) . '">', '</a>' ); ?>
			</div>

			<div class="theme-badge">
				<img src="<?php echo BAVOTASAN_THEME_URL; ?>/library/images/screenshot_sml.jpg" />
			</div>
			<hr />

			<div class="changelog headline-feature dfw">
				<h2><?php _e( 'Video Preview', 'magazine-premium' ); ?></h2>
			</div>

			<div class="videoWrapper">
				<iframe width="853" height="480" src="https://www.youtube.com/embed/LrxZ298e6yY" frameborder="0" allowfullscreen></iframe>
			</div>

			<div class="changelog headline-feature dfw">
				<h2><?php _e( 'The Customizer', 'magazine-premium' ); ?></h2>

				<div class="featured-image dfw-container">
					<img src="<?php echo BAVOTASAN_THEME_URL; ?>/library/images/customizer.jpg" />
				</div>

				<p><?php printf( __( 'Most theme options for <em>%1$s</em> are controlled under %2$sAppearance &rarr; Customize%3$s. From there, you can modify layout, colors, custom menus, and more.', 'magazine-premium' ), BAVOTASAN_THEME_NAME, '<a href="' . admin_url( 'customize.php' ) . '">', '</a>' ); ?></p>

				<h3><?php _e( 'Logo', 'magazine-premium' ); ?></h3>

				<p><?php _e( 'To add a logo, click <strong>Select Image</strong> to activate the media uploader. Drag over your  image or select one from your media library.', 'magazine-premium' ); ?></p>

				<h3><?php _e( 'Site &amp; Main Content Width', 'magazine-premium' ); ?></h3>

				<p><?php _e( 'There are four width options for your site: 1200px, 960px, 640px &amp; Full. You can select the width of your main content, based on a 12 column grid. Resizing your main content will also resize your sidebar. If two sidebars are displayed, you can select the width of the first sidebar as well.', 'magazine-premium' ); ?></p>

				<h3><?php _e( 'Sidebar Layout', 'magazine-premium' ); ?></h3>

				<p><?php printf( __( 'With the sidebar layout option, you can decide whether to display your sidebar(s) on the left or right of your main content. To display two sidebars, first add a widget to the second sidebar under %1$sAppearance &rarr; Widgets%2$s. Once that&rsquo;s done, the two-sidebar option will appear.', 'magazine-premium' ), '<a href="' . admin_url( 'widgets.php' ) . '">', '</a>' ); ?></p>
			</div>
			<hr />

			<div class="changelog headline-feature dfw">
				<h2><?php _e( 'Custom Menus', 'magazine-premium' ); ?></h2>

				<p><?php printf( __( '<em>%s</em> includes three Custom Menu locations: the Primary top menu, the Secondary top menu and the Social menu.', 'magazine-premium' ), BAVOTASAN_THEME_NAME ); ?></p>

				<p><?php printf( __( 'To add a navigation menu to the header, go to %1$sAppearance &rarr; Menus%2$s. By default, a list of categories will appear in this location if no custom menu is set.', 'magazine-premium' ), '<a href="' . admin_url( 'nav-menus.php' ) . '">', '</a>' ); ?></p>

				<h3><?php _e( 'Social Menu', 'magazine-premium' ); ?></h3>

				<div class="featured-image dfw-container">
					<img src="<?php echo BAVOTASAN_THEME_URL; ?>/library/images/social-menu-setup.jpg" />
				</div>

				<p><?php printf( __( 'To use the social menu, go to %1$sAppearance &rarr; Menus%2$s and create a new menu. Call it "Social" just to make it easy to remember. Use the Link panel on the left to add any of the following social sites:', 'magazine-premium' ), '<a href="' . admin_url( 'nav-menus.php' ) . '">', '</a>' ); ?></p>

				<ul>
					<li>Twitter</li>
					<li>Facebook</li>
					<li>Pinterest</li>
					<li>Google+</li>
					<li>Dribbble</li>
					<li>GitHub</li>
					<li>Tumblr</li>
					<li>YouTube</li>
					<li>Flickr</li>
					<li>Vimeo</li>
					<li>Instagram</li>
					<li>LinkedIn</li>
					<li>Bitbucket</li>
				</ul>

				<p><?php _e( 'Once you&rsquo;ve added the social sites you want with a link to each profile - like <code>https://twitter.com/bavotasan</code> - check the Social box at the bottom of the menu and click <strong>Save Menu</strong>. Your social links will now be displayed at the top right of your site.', 'magazine-premium' );?></p>
			</div>
			<hr />

			<div class="changelog headline-feature dfw">
				<h2><?php _e( 'Content Slider', 'magazine-premium' ); ?></h2>

				<div class="featured-image dfw-container">
					<img src="<?php echo BAVOTASAN_THEME_URL; ?>/library/images/slider.jpg" />
				</div>

				<p><?php printf( __( 'There are four slider options built-in to <em>%1$s</em>. Each one is responsive and offers a different design. To learn more about using the slider admin page, please refer to %2$smy documentation section%3$s.', 'magazine-premium' ), BAVOTASAN_THEME_NAME, '<a href="//themes.bavotasan.com/documentation/the-slider-admin/">', '</a>' ); ?></p>
			</div>
			<hr />

			<div class="changelog headline-feature dfw">
				<h2><?php _e( 'Custom Slider Image', 'magazine-premium' ); ?></h2>

				<p><?php _e( 'You have an option to display a custom slider image for each posts, through the Custom Slider Image panel. Click <strong>Set Image</strong> to open the media library and select an image or upload a new one. Click <strong>Update</strong> or <strong>Publish</strong> when you&rsquo;re done.', 'magazine-premium' ); ?></p>

				<div class="featured-image dfw-container">
					<img src="<?php echo BAVOTASAN_THEME_URL; ?>/library/images/custom-header.jpg" />
				</div>

				<p><?php _e( 'If you don&rsquo;t set a custom slider image on a page, the featured image will be displayed instead. You must set either one or the other or the slider will not function properly.', 'magazine-premium' ); ?></p>
			</div>
			<hr />

			<div class="changelog headline-feature dfw">
				<h2><?php _e( 'Jetpack', 'magazine-premium' ); ?></h2>

				<div class="featured-image dfw-container">
					<img src="<?php echo BAVOTASAN_THEME_URL; ?>/library/images/jetpack.jpg" />
				</div>

				<h3><?php _e( 'Tiled Galleries', 'magazine-premium' ); ?></h3>

				<p><?php printf( __( '%1$sJetpack&rsquo;s Tiled Galleries%2$s will display your images in a beautiful mosaic layout. Go to %3$sJetpack &rarr; Settings%4$s to turn it on. ', 'magazine-premium' ), '<a href="//jetpack.me/support/tiled-galleries/">', '</a>', '<a href="' . admin_url( 'admin.php?page=jetpack_modules' ) . '">', '</a>' ); ?></p>

				<h3><?php _e( 'Carousel', 'magazine-premium' ); ?></h3>

				<p><?php printf( __( 'With %1$sJetpack&rsquo;s Carousel%2$s, clicking on one of your gallery images will open up a featured lightbox slideshow. Turn it on by going to %3$sJetpack &rarr; Settings%4$s.', 'magazine-premium' ), '<a href="//jetpack.me/support/carousel/">', '</a>', '<a href="' . admin_url( 'admin.php?page=jetpack_modules' ) . '">', '</a>' ); ?></p>
			</div>
			<hr />

			<div class="changelog headline-feature dfw">
				<h2><?php _e( 'The Extended Footer', 'magazine-premium' ); ?></h2>

				<div class="featured-image dfw-container">
					<img src="<?php echo BAVOTASAN_THEME_URL; ?>/library/images/extended-footer.jpg" />
				</div>

				<p><?php printf( __( 'To display widgets in your footer go to %1$sAppearance &rarr; Widgets%2$s and add at least one widget to the Extended Footer area.', 'magazine-premium' ), '<a href="' . admin_url( 'widgets.php' ) . '">', '</a>' ); ?></p>

				<p><?php printf( __( 'You can include a copyright notice through the Footer section of the %1$sCustomizer%2$s.', 'magazine-premium' ), '<a href="' . admin_url( 'customize.php' ) . '">', '</a>' ); ?></p>
			</div>
			<hr />

			<div class="changelog headline-feature dfw">
				<h2><?php _e( 'Shortcodes', 'magazine-premium' ); ?></h2>

				<p><?php printf( __( '<em>%1$s</em> comes with tons of great shortcodes to help spice up your posts and pages. Learn more by %2$schecking out the demo%3$s.', 'magazine-premium' ), BAVOTASAN_THEME_NAME, '<a href="//demos.bavotasan.com/' . sanitize_title( BAVOTASAN_THEME_NAME ) . '/shortcodes/">', '</a>' ); ?></p>
			</div>
			<hr />

			<div class="changelog headline-feature dfw">
				<h2><?php _e( 'Full-Width Post/Page', 'magazine-premium' ); ?></h2>

				<div class="featured-image dfw-container">
					<img src="<?php echo BAVOTASAN_THEME_URL; ?>/library/images/full-width-page.jpg" />
				</div>

				<p><?php _e( 'To set a full-width post or page, meaning one without any sidebars, check the box in the Layout panel when you&rsquo;re editing the post or page in the admin.', 'magazine-premium' ); ?></p>
			</div>
			<hr />

			<div class="changelog headline-feature dfw">
				<h2><?php _e( 'Pull Quotes', 'magazine-premium' ); ?></h2>

				<div class="featured-image dfw-container">
					<img src="<?php echo BAVOTASAN_THEME_URL; ?>/library/images/pull-quotes.jpg" />
				</div>

				<p><?php _e( 'You can easily include a pull quote within your text by using the following code within the Text/HTML editor:', 'magazine-premium' ); ?></p>

				<p><code><?php _e( '&lt;blockquote class="pullquote"&gt;This is a pull quote that will appear within your text.&lt;/blockquote&gt;', 'magazine-premium' ); ?></code></p>
				<p><?php _e( 'You can also align it to the right with this code:', 'magazine-premium' ); ?></p>

				<p><code><?php _e( '&lt;blockquote class="pullquote alignright"&gt;This is a pull quote that will appear within your text.&lt;/blockquote&gt;', 'magazine-premium' ); ?></code></p>
			</div>
			<hr />

			<p><?php printf( __( 'For more information, check out the %1$sDocumentation &amp; FAQs%2$s section on my site.', 'magazine-premium' ), '<a href="//themes.bavotasan.com/documentation/" target="_blank">', '</a>' ); ?></p>
		</div>
		<?php
	}
}
$bavotasan_documentation = new Bavotasan_Documentation;