<?php
/**
 * Set up the default theme options
 *
 * @since 2.0.0
 */
function bavotasan_default_theme_options() {
	//delete_option( 'theme_mods_magazine_premium' );
	return array(
		'width' => '',
		'layout' => 'right',
		'primary' => 'c8',
		'secondary' => 'c2',
		'tagline' => 'on',
		'display_author' => 'on',
		'display_date' => 'on',
		'display_comment_count' => '',
		'display_categories' => '',
		'excerpt_content' => 'excerpt',
		'page_background_color' => '#ffffff',
		'grid' => '3',
		'number' => '6',
		'link_color' => '#0089C4',
		'link_hover_color' => '#222222',
		'main_text_color' => '#444444',
		'nav_text_color' => '#eeeeee',
		'nav_text_hover_color' => '#eeeeee',
		'nav_background_color' => '#272727',
		'nav_background_hover_color' => '#111111',
		'nav_font' => 'PT Sans, sans-serif',
		'nav_font_size' => '15',
		'sub_nav_font_size' => '12',
		'headers_color' => '#222222',
		'read_more' => 'Read more &rarr;',
		'extended_footer_columns' => 'c4',
		'logo' => '',
		'copyright' => 'Copyright &copy; ' . date( 'Y' ) . ' <a href="' . esc_url( home_url() ) . '">' . get_bloginfo( 'name' ) .'</a>. All Rights Reserved.',
		'main_text_font' => 'Open Sans, sans-serif',
		'main_text_font_size' => '14',
		'headers_font' => 'Lato, serif',
		'site_title_font' => 'Quattrocento, serif',
		'site_title_font_size' => '48',
		'site_description_font' => 'Lato Light, sans-serif',
		'site_description_font_size' => '18',
		'post_title_font' => 'Lato, sans-serif',
		'post_title_font_size' => '28',
		'post_meta_font' => 'Lato Light, sans-serif',
		'post_meta_font_size' => '13',
		'post_category_font' => 'Lato Light, sans-serif',
		'post_category_font_size' => '13',
		'header_alignment' => 'fl',
		'1_image_width' => '560',
		'2_image_width' => '260',
		'3_image_width' => '160',
		'image_bar_category' => '0',
		'image_bar_columns' => 'c2',
		'image_bar_display' => 'on',
		'read_more_text_color' => '#ffffff',
		'read_more_background_color' => '#444444',
		'sidebar_background_color' => '#F6F6F6',
	);
}

function bavotasan_theme_options() {
	$bavotasan_default_theme_options = bavotasan_default_theme_options();

	$return = array();
	foreach( $bavotasan_default_theme_options as $option => $value ) {
		$return[$option] = get_theme_mod( $option, $value );
	}

	return $return;
}

if ( class_exists( 'WP_Customize_Control' ) ) {
	class Custom_Text_Control extends WP_Customize_Control {
	    public $text = ''; // we add this for the extra description
	    public function render_content() {
	    ?>
	    <label><?php echo esc_html( $this->text ); ?></label>
	    <?php
	    }
	}

	class Bavotasan_Post_Layout_Control extends WP_Customize_Control {
	    public function render_content() {
			if ( empty( $this->choices ) )
				return;

			$name = '_customize-radio-' . $this->id;

			?>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<?php
			foreach ( $this->choices as $value => $label ) :
				?>
				<label>
					<input type="radio" value="<?php echo esc_attr( $value ); ?>" name="<?php echo esc_attr( $name ); ?>" <?php $this->link(); checked( $this->value(), $value ); ?> />
					<?php
					$value = ( is_active_sidebar( 'second-sidebar' ) ) ? $value . ' second-sidebar' : $value;
					echo '<div class="' . esc_attr( $value ) . '"></div>'; ?>
				</label>
				<?php
			endforeach;
			echo '<p class="description">' . sprintf( __( 'For layout options with two sidebars, add at least one widget to the Second Sidebar area on the %1$sWidgets admin page%2$s.', 'magazine-premium' ), '<a href="' . esc_url( admin_url( 'widgets.php' ) ) . '">', '</a>' ) . '</p>';
	    }
	}
}

class Bavotasan_Customizer {
	public function __construct() {
		add_action( 'admin_bar_menu', array( $this, 'admin_bar_menu' ), 2 );

		add_action( 'customize_register', array( $this, 'customize_register' ) );
		add_action( 'customize_controls_print_styles', array( $this, 'customize_controls_print_styles' ) );

		$mods = get_option( 'theme_mods_magazine_premium' );
		if ( empty( $mods ) )
			add_option( 'theme_mods_magazine_premium', get_option( 'mp_theme_options' ) );
	}

	public function customize_controls_print_styles() {
		wp_enqueue_style( 'bavotasan_customizer', BAVOTASAN_THEME_URL . '/library/css/admin/customizer.css' );
	}

	/**
	 * Add a 'Theme Options' menu item to the admin bar
	 *
	 * This function is attached to the 'admin_bar_menu' action hook.
	 *
	 * @since 1.0.0
	 */
	public function admin_bar_menu( $wp_admin_bar ) {
	    if ( current_user_can( 'edit_theme_options' ) && is_admin_bar_showing() )
	    	$wp_admin_bar->add_node( array( 'parent' => 'bavotasan_toolbar', 'id' => 'customize_theme', 'title' => __( 'Customize', 'magazine-premium' ), 'href' => admin_url( 'customize.php' ) ) );
	}

	/**
	 * Adds theme options to the Customizer screen
	 *
	 * This function is attached to the 'customize_register' action hook.
	 *
	 * @param	class $wp_customize
	 *
	 * @since 1.0.0
	 */
	public function customize_register( $wp_customize ) {
		$bavotasan_default_theme_options = bavotasan_default_theme_options();
		$advanced_front_page = get_option( 'mp_advanced_front_page' );

		$wp_customize->add_setting( 'tagline', array(
			'default' => $bavotasan_default_theme_options['tagline'],
            'sanitize_callback' => array( $this, 'sanitize_checkbox' ),
		) );

		$wp_customize->add_control( 'tagline', array(
			'label' => __( 'Display Tagline', 'magazine-premium' ),
			'section' => 'title_tagline',
			'type' => 'checkbox',
		) );

		$wp_customize->add_setting( 'logo', array(
			'default' => $bavotasan_default_theme_options['logo'],
            'sanitize_callback' => 'esc_url',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'logo', array(
			'label' => __( 'Site Logo', 'magazine-premium' ),
			'section' => 'title_tagline',
		) ) );

		$wp_customize->add_setting( 'header_alignment', array(
			'default' => $bavotasan_default_theme_options['header_alignment'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'header_alignment', array(
			'label' => __( 'Header Alignment', 'magazine-premium' ),
			'section' => 'title_tagline',
			'type' => 'select',
			'choices' => array(
				'fl' => __( 'Left', 'magazine-premium' ),
				'fr' => __( 'Right', 'magazine-premium' ),
				'center' => __( 'Center', 'magazine-premium' ),
			),
		) );

		// Layout section panel
		$wp_customize->add_section( 'bavotasan_layout', array(
			'title' => __( 'Layout', 'magazine-premium' ),
			'priority' => 35,
		) );

		$wp_customize->add_setting( 'width', array(
			'default' => $bavotasan_default_theme_options['width'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'width', array(
			'label' => __( 'Site Width', 'magazine-premium' ),
			'section' => 'bavotasan_layout',
			'priority' => 10,
			'type' => 'select',
			'choices' => array(
				'' => '1200px',
				'w960' => __( '960px', 'magazine-premium' ),
				'w640' => __( '640px', 'magazine-premium' ),
				'wfull' => __( 'Full Width', 'magazine-premium' ),
			),
		) );

		$wp_customize->add_setting( 'layout', array(
			'default' => $bavotasan_default_theme_options['layout'],
            'sanitize_callback' => 'esc_attr',
		) );

		$layout_choices = array(
			'none' => __( 'No Sidebars', 'magazine-premium' ),
			'left' => __( 'Left', 'magazine-premium' ),
			'right' => __( 'Right', 'magazine-premium' ),
		);

		if ( is_active_sidebar( 'second-sidebar' ) )
			$layout_choices['separate'] = __( 'Separate', 'magazine-premium' );

		$wp_customize->add_control( new Bavotasan_Post_Layout_Control( $wp_customize, 'layout', array(
			'label' => __( 'Sidebar Layout', 'magazine-premium' ),
			'section' => 'bavotasan_layout',
			'size' => false,
			'priority' => 15,
			'choices' => $layout_choices,
		) ) );


		$choices =  array(
			'c2' => '17%',
			'c3' => '25%',
			'c4' => '34%',
			'c5' => '42%',
			'c6' => '50%',
			'c7' => '58%',
			'c8' => '66%',
			'c9' => '75%',
			'c10' => '83%',
		);

		$wp_customize->add_setting( 'primary', array(
			'default' => $bavotasan_default_theme_options['primary'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'primary', array(
			'label' => __( 'Main Content', 'magazine-premium' ),
			'section' => 'bavotasan_layout',
			'priority' => 20,
			'type' => 'select',
			'choices' => $choices,
		) );

		if ( is_active_sidebar( 'second-sidebar' ) ) {
			$wp_customize->add_setting( 'secondary', array(
				'default' => $bavotasan_default_theme_options['secondary'],
	            'sanitize_callback' => 'esc_attr',
			) );

			$wp_customize->add_control( 'secondary', array(
				'label' => __( 'First Sidebar', 'magazine-premium' ),
				'section' => 'bavotasan_layout',
				'priority' => 25,
				'type' => 'select',
				'choices' => $choices,
			) );
		}

		$wp_customize->add_setting( 'read_more', array(
			'default' => $bavotasan_default_theme_options['read_more'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'read_more', array(
			'label' => __( '"Read More" Text', 'magazine-premium' ),
			'section' => 'bavotasan_layout',
			'priority' => 33,
			'type' => 'text',
		) );

		// Front Page
		$wp_customize->add_section( 'bavotasan_front_page', array(
			'title' => __( 'Basic Front Page', 'magazine-premium' ),
			'priority' => 40,
		) );

	    $wp_customize->add_setting( 'basic_text', array(
			'default' => '',
            'sanitize_callback' => 'esc_attr',
		) );

	    $wp_customize->add_control( new Custom_Text_Control( $wp_customize, 'basic_text', array(
			'section' => 'bavotasan_front_page',
	        'text' => __( 'These settings only work if you haven\'t added sections to the Advanced Front Page.', 'magazine-premium' ),
			'priority' => 1,
	        ) )
	    );

		$wp_customize->add_setting( 'excerpt_content', array(
			'default' => $bavotasan_default_theme_options['excerpt_content'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'excerpt_content', array(
			'label' => __( 'Post Content Display', 'magazine-premium' ),
			'section' => 'bavotasan_front_page',
			'type' => 'radio',
			'choices' => array(
				'excerpt' => __( 'Teaser Excerpt', 'magazine-premium' ),
				'content' => __( 'Full Content', 'magazine-premium' ),
			),
		) );

		$wp_customize->add_setting( 'grid', array(
			'default' => $bavotasan_default_theme_options['grid'],
            'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'grid', array(
			'label' => __( 'Grid Layout', 'magazine-premium' ),
			'section' => 'bavotasan_front_page',
			'type' => 'radio',
			'choices' => array(
				'1' => __( 'Single', 'magazine-premium' ),
				'2' => __( 'Single - Two Columns', 'magazine-premium' ),
				'3' => __( 'Single - Two Columns - Three Columns', 'magazine-premium' ),
				'4' => __( 'Single - Three Columns', 'magazine-premium' ),
			),
		) );

		$wp_customize->add_setting( 'number', array(
			'default' => $bavotasan_default_theme_options['number'],
			'sanitize_callback' => array( $this, 'sanitize_int' ),
		) );

		$wp_customize->add_control( 'number', array(
			'label' => __( 'Number of Posts', 'magazine-premium' ),
			'section' => 'bavotasan_front_page',
		) );

		$wp_customize->add_setting( '1_image_width', array(
			'default' => $bavotasan_default_theme_options['1_image_width'],
			'sanitize_callback' => array( $this, 'sanitize_int' ),
		) );

		$wp_customize->add_control( '1_image_width', array(
			'label' => __( '1 Column Image Width (pixels)', 'magazine-premium' ),
			'section' => 'bavotasan_front_page',
			'priority' => 60,
		) );

		$wp_customize->add_setting( '2_image_width', array(
			'default' => $bavotasan_default_theme_options['2_image_width'],
			'sanitize_callback' => array( $this, 'sanitize_int' ),
		) );

		$wp_customize->add_control( '2_image_width', array(
			'label' => __( '2 Column Image Width (pixels)', 'magazine-premium' ),
			'section' => 'bavotasan_front_page',
			'priority' => 70,
		) );

		$wp_customize->add_setting( '3_image_width', array(
			'default' => $bavotasan_default_theme_options['3_image_width'],
			'sanitize_callback' => array( $this, 'sanitize_int' ),
		) );

		$wp_customize->add_control( '3_image_width', array(
			'label' => __( '3 Column Image Width (pixels)', 'magazine-premium' ),
			'section' => 'bavotasan_front_page',
			'priority' => 80,
		) );

		// Advanced Front Page
		$wp_customize->add_section( 'mp_advanced_front_page', array(
			'title' => __( 'Advanced Front Page', 'magazine-premium' ),
			'priority' => 45,
		) );

	    $wp_customize->add_setting( 'text', array(
			'default' => '',
            'sanitize_callback' => 'esc_attr',
		) );

	    $wp_customize->add_control( new Custom_Text_Control( $wp_customize, 'text', array(
			'section' => 'mp_advanced_front_page',
	        'text' => __( 'Go to the Advanced Front Page admin page for more options.', 'magazine-premium' )
	        ) )
	    );

		$wp_customize->add_setting( 'mp_advanced_front_page[lower_content_width]', array(
			'default' => $advanced_front_page['lower_content_width'],
			'type' => 'option',
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'bavotasan_lower_content_width', array(
			'label' => __( 'Lower Content Width', 'magazine-premium' ),
			'section' => 'mp_advanced_front_page',
			'settings' => 'mp_advanced_front_page[lower_content_width]',
			'type' => 'select',
			'choices' => $choices,
		) );

		$wp_customize->add_setting( 'mp_advanced_front_page[lower_content_alignment]', array(
			'default' => $advanced_front_page['lower_content_alignment'],
			'type' => 'option',
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'bavotasan_lower_content_alignment', array(
			'label' => __( 'Lower Sidebar Position', 'magazine-premium' ),
			'section' => 'mp_advanced_front_page',
			'settings' => 'mp_advanced_front_page[lower_content_alignment]',
			'type' => 'select',
			'choices' => array(
				'left' => __( 'Left', 'magazine-premium' ),
				'right' => __( 'Right', 'magazine-premium' ),
			),
		) );

		// Fonts panel
		$mixed_fonts = array_merge( mp_websafe_fonts() , bavotasan_google_fonts() );
		asort( $mixed_fonts );

		$wp_customize->add_section( 'bavotasan_fonts', array(
			'title' => __( 'Fonts', 'magazine-premium' ),
			'priority' => 50,
		) );

		$wp_customize->add_setting( 'main_text_font', array(
			'default' => $bavotasan_default_theme_options['main_text_font'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'main_text_font', array(
			'label' => __( 'Main Text', 'magazine-premium' ),
			'section' => 'bavotasan_fonts',
			'priority' => 10,
			'type' => 'select',
			'choices' => $mixed_fonts,
		) );

		$wp_customize->add_setting( 'main_text_font_size', array(
			'default' => $bavotasan_default_theme_options['main_text_font_size'],
            'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'main_text_font_size', array(
			'label' => __( 'Main Text Size (in pixels)', 'magazine-premium' ),
			'section' => 'bavotasan_fonts',
			'priority' => 11,
		) );

		$wp_customize->add_setting( 'headers_font', array(
			'default' => $bavotasan_default_theme_options['headers_font'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'headers_font', array(
			'label' => __( 'Headers (h1, h2, h3, etc...)', 'magazine-premium' ),
			'section' => 'bavotasan_fonts',
			'priority' => 15,
			'type' => 'select',
			'choices' => $mixed_fonts,
		) );

		$wp_customize->add_setting( 'site_title_font', array(
			'default' => $bavotasan_default_theme_options['site_title_font'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'site_title_font', array(
			'label' => __( 'Site Title', 'magazine-premium' ),
			'section' => 'bavotasan_fonts',
			'priority' => 20,
			'type' => 'select',
			'choices' => $mixed_fonts,
		) );

		$wp_customize->add_setting( 'site_title_font_size', array(
			'default' => $bavotasan_default_theme_options['site_title_font_size'],
            'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'site_title_font_size', array(
			'label' => __( 'Site Title Size (in pixels)', 'magazine-premium' ),
			'section' => 'bavotasan_fonts',
			'priority' => 21,
		) );

		$wp_customize->add_setting( 'site_description_font', array(
			'default' => $bavotasan_default_theme_options['site_description_font'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'site_description_font', array(
			'label' => __( 'Site Description', 'magazine-premium' ),
			'section' => 'bavotasan_fonts',
			'priority' => 25,
			'type' => 'select',
			'choices' => $mixed_fonts,
		) );

		$wp_customize->add_setting( 'site_description_font_size', array(
			'default' => $bavotasan_default_theme_options['site_description_font_size'],
            'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'site_description_font_size', array(
			'label' => __( 'Site Description Size (in pixels)', 'magazine-premium' ),
			'section' => 'bavotasan_fonts',
			'priority' => 26,
		) );

		$wp_customize->add_setting( 'post_title_font', array(
			'default' => $bavotasan_default_theme_options['post_title_font'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'post_title_font', array(
			'label' => __( 'Post Title', 'magazine-premium' ),
			'section' => 'bavotasan_fonts',
			'priority' => 30,
			'type' => 'select',
			'choices' => $mixed_fonts,
		) );

		$wp_customize->add_setting( 'post_title_font_size', array(
			'default' => $bavotasan_default_theme_options['post_title_font_size'],
            'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'post_title_font_size', array(
			'label' => __( 'Post Title Size (in pixels)', 'magazine-premium' ),
			'section' => 'bavotasan_fonts',
			'priority' => 31,
		) );

		$wp_customize->add_setting( 'post_meta_font', array(
			'default' => $bavotasan_default_theme_options['post_meta_font'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'post_meta_font', array(
			'label' => __( 'Post Meta', 'magazine-premium' ),
			'section' => 'bavotasan_fonts',
			'priority' => 35,
			'type' => 'select',
			'choices' => $mixed_fonts,
		) );

		$wp_customize->add_setting( 'post_meta_font_size', array(
			'default' => $bavotasan_default_theme_options['post_meta_font_size'],
            'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'post_meta_font_size', array(
			'label' => __( 'Post Meta Size (in pixels)', 'magazine-premium' ),
			'section' => 'bavotasan_fonts',
			'priority' => 36,
		) );

		$wp_customize->add_setting( 'post_category_font', array(
			'default' => $bavotasan_default_theme_options['post_category_font'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'post_category_font', array(
			'label' => __( 'Post Category', 'magazine-premium' ),
			'section' => 'bavotasan_fonts',
			'priority' => 40,
			'type' => 'select',
			'choices' => $mixed_fonts,
		) );

		$wp_customize->add_setting( 'post_category_font_size', array(
			'default' => $bavotasan_default_theme_options['post_category_font_size'],
            'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'post_category_font_size', array(
			'label' => __( 'Post Category Size (in pixels)', 'magazine-premium' ),
			'section' => 'bavotasan_fonts',
			'priority' => 41,
		) );

		$wp_customize->add_setting( 'nav_font', array(
			'default' => $bavotasan_default_theme_options['nav_font'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'nav_font', array(
			'label' => __( 'Nav Text', 'magazine-premium' ),
			'section' => 'bavotasan_fonts',
			'priority' => 45,
			'type' => 'select',
			'choices' => $mixed_fonts,
		) );

		$wp_customize->add_setting( 'nav_font_size', array(
			'default' => $bavotasan_default_theme_options['nav_font_size'],
            'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'nav_font_size', array(
			'label' => __( 'Primary Nav Text Size (in pixels)', 'magazine-premium' ),
			'section' => 'bavotasan_fonts',
			'priority' => 46,
		) );

		$wp_customize->add_setting( 'sub_nav_font_size', array(
			'default' => $bavotasan_default_theme_options['sub_nav_font_size'],
            'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'sub_nav_font_size', array(
			'label' => __( 'Secondary Nav Text Size (in pixels)', 'magazine-premium' ),
			'section' => 'bavotasan_fonts',
			'priority' => 47,
		) );

		// Color panel
		$wp_customize->add_setting( 'page_background_color', array(
			'default' => $bavotasan_default_theme_options['page_background_color'],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'page_background_color', array(
			'label' => __( 'Page Background Color', 'magazine-premium' ),
			'section'  => 'colors',
			'priority' => 11,
		) ) );

		$wp_customize->add_setting( 'headers_color', array(
			'default' => $bavotasan_default_theme_options['headers_color'],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'headers_color', array(
			'label' => __( 'Headers (h1, h2, h3, etc...)', 'magazine-premium' ),
			'section'  => 'colors',
			'priority' => 20,
		) ) );

		$wp_customize->add_setting( 'main_text_color', array(
			'default' => $bavotasan_default_theme_options['main_text_color'],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'main_text_color', array(
			'label' => __( 'Main Text Color', 'magazine-premium' ),
			'section'  => 'colors',
			'priority' => 25,
		) ) );

		$wp_customize->add_setting( 'link_color', array(
			'default' => $bavotasan_default_theme_options['link_color'],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'link_color', array(
			'label' => __( 'Link Color', 'magazine-premium' ),
			'section'  => 'colors',
			'priority' => 50,
		) ) );

		$wp_customize->add_setting( 'link_hover_color', array(
			'default' => $bavotasan_default_theme_options['link_hover_color'],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'link_hover_color', array(
			'label' => __( 'Link Hover Color', 'magazine-premium' ),
			'section'  => 'colors',
			'priority' => 55,
		) ) );

		$wp_customize->add_setting( 'read_more_text_color', array(
			'default' => $bavotasan_default_theme_options['read_more_text_color'],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'read_more_text_color', array(
			'label' => __( 'Read More Text Color', 'magazine-premium' ),
			'section'  => 'colors',
			'priority' => 60,
		) ) );

		$wp_customize->add_setting( 'read_more_background_color', array(
			'default' => $bavotasan_default_theme_options['read_more_background_color'],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'read_more_background_color', array(
			'label' => __( 'Read More Background Color', 'magazine-premium' ),
			'section'  => 'colors',
			'priority' => 65,
		) ) );

		$wp_customize->add_setting( 'sidebar_background_color', array(
			'default' => $bavotasan_default_theme_options['sidebar_background_color'],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sidebar_background_color', array(
			'label' => __( 'Sidebar Background Color', 'magazine-premium' ),
			'section'  => 'colors',
			'priority' => 70,
		) ) );

		$wp_customize->add_setting( 'nav_text_color', array(
			'default' => $bavotasan_default_theme_options['nav_text_color'],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'nav_text_color', array(
			'label' => __( 'Nav Text Color', 'magazine-premium' ),
			'section'  => 'colors',
			'priority' => 75,
		) ) );

		$wp_customize->add_setting( 'nav_text_hover_color', array(
			'default' => $bavotasan_default_theme_options['nav_text_hover_color'],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'nav_text_hover_color', array(
			'label' => __( 'Nav Text Hover Color', 'magazine-premium' ),
			'section'  => 'colors',
			'priority' => 76,
		) ) );

		$wp_customize->add_setting( 'nav_background_color', array(
			'default' => $bavotasan_default_theme_options['nav_background_color'],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'nav_background_color', array(
			'label' => __( 'Nav Background Color', 'magazine-premium' ),
			'section'  => 'colors',
			'priority' => 77,
		) ) );

		$wp_customize->add_setting( 'nav_background_hover_color', array(
			'default' => $bavotasan_default_theme_options['nav_background_hover_color'],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'nav_background_hover_color', array(
			'label' => __( 'Nav Background Hover Color', 'magazine-premium' ),
			'section'  => 'colors',
			'priority' => 78,
		) ) );

		// Posts panel
		$wp_customize->add_section( 'bavotasan_posts', array(
			'title' => __( 'Posts', 'magazine-premium' ),
			'priority' => 45,
		) );

		$wp_customize->add_setting( 'display_categories', array(
			'default' => $bavotasan_default_theme_options['display_categories'],
            'sanitize_callback' => array( $this, 'sanitize_checkbox' ),
		) );

		$wp_customize->add_control( 'display_categories', array(
			'label' => __( 'Display Categories', 'magazine-premium' ),
			'section' => 'bavotasan_posts',
			'type' => 'checkbox',
		) );

		$wp_customize->add_setting( 'display_author', array(
			'default' => $bavotasan_default_theme_options['display_author'],
            'sanitize_callback' => array( $this, 'sanitize_checkbox' ),
		) );

		$wp_customize->add_control( 'display_author', array(
			'label' => __( 'Display Author', 'magazine-premium' ),
			'section' => 'bavotasan_posts',
			'type' => 'checkbox',
		) );

		$wp_customize->add_setting( 'display_date', array(
			'default' => $bavotasan_default_theme_options['display_date'],
            'sanitize_callback' => array( $this, 'sanitize_checkbox' ),
		) );

		$wp_customize->add_control( 'display_date', array(
			'label' => __( 'Display Date', 'magazine-premium' ),
			'section' => 'bavotasan_posts',
			'type' => 'checkbox',
		) );

		$wp_customize->add_setting( 'display_comment_count', array(
			'default' => $bavotasan_default_theme_options['display_comment_count'],
            'sanitize_callback' => array( $this, 'sanitize_checkbox' ),
		) );

		$wp_customize->add_control( 'display_comment_count', array(
			'label' => __( 'Display Comment Count', 'magazine-premium' ),
			'section' => 'bavotasan_posts',
			'type' => 'checkbox',
		) );

		// Footer panel
		$wp_customize->add_section( 'bavotasan_footer', array(
			'title' => __( 'Footer', 'magazine-premium' ),
			'priority' => 50,
		) );

		$wp_customize->add_setting( 'image_bar_display', array(
			'default' => $bavotasan_default_theme_options['image_bar_display'],
            'sanitize_callback' => array( $this, 'sanitize_checkbox' ),
		) );

		$wp_customize->add_control( 'image_bar_display', array(
			'label' => __( 'Display Image Bar', 'magazine-premium' ),
			'section' => 'bavotasan_footer',
			'type' => 'checkbox',
		) );

		$wp_customize->add_setting( 'image_bar_category', array(
			'default' => $bavotasan_default_theme_options['image_bar_category'],
            'sanitize_callback' => 'absint',
		) );

		$categories = get_categories();
		$cats = array();
		$cats[0] = __( 'All', 'magazine-premium' );
		foreach ( $categories as $category ) {
		    $cats[$category->term_id] = $category->name;
		}

		$wp_customize->add_control( 'image_bar_category', array(
			'label' => __( 'Image Bar Category', 'magazine-premium' ),
			'section' => 'bavotasan_footer',
			'priority' => 10,
			'type' => 'select',
			'choices' => $cats,
		) );

		$wp_customize->add_setting( 'image_bar_columns', array(
			'default' => $bavotasan_default_theme_options['image_bar_columns'],
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'image_bar_columns', array(
			'label' => __( 'Image Bar Columns', 'magazine-premium' ),
			'section' => 'bavotasan_footer',
			'priority' => 10,
			'type' => 'select',
			'choices' => array(
				'c4' => __( '3 Columns', 'magazine-premium' ),
				'c3' => __( '4 Columns', 'magazine-premium' ),
				'c2' => __( '6 Columns', 'magazine-premium' ),
			),
		) );

		$wp_customize->add_setting( 'extended_footer_columns', array(
			'default' => $bavotasan_default_theme_options['extended_footer_columns'],
			'transport' => 'postMessage',
            'sanitize_callback' => 'esc_attr',
		) );

		$wp_customize->add_control( 'extended_footer_columns', array(
			'label' => __( 'Extended Footer Columns', 'magazine-premium' ),
			'section' => 'bavotasan_footer',
			'priority' => 15,
			'type' => 'select',
			'choices' => array(
				'c12' => __( '1 Column', 'magazine-premium' ),
				'c6' => __( '2 Columns', 'magazine-premium' ),
				'c4' => __( '3 Columns', 'magazine-premium' ),
				'c3' => __( '4 Columns', 'magazine-premium' ),
				'c2' => __( '6 Columns', 'magazine-premium' ),
			),
		) );

		$wp_customize->add_setting( 'copyright', array(
			'default' => $bavotasan_default_theme_options['copyright'],
            'sanitize_callback' => 'esc_textarea',
		) );

		$wp_customize->add_control( 'copyright', array(
			'label' => __( 'Copyright Notice', 'magazine-premium' ),
			'section' => 'bavotasan_footer',
			'priority' => 20,
		) );

		if ( $wp_customize->is_preview() && ! is_admin() )
			add_action( 'wp_footer', array( $this, 'bavotasan_customize_preview' ), 21);
	}

	/**
	 * jQuery for Customizer screen
	 *
	 * @since 1.0.0
	 */
	public function bavotasan_customize_preview() {
		?>
<script>
( function( $ ){
	wp.customize( 'extended_footer_columns', function( value ) {
		value.bind( function( to ) {
			$( '.footer-widget' ).removeClass( 'c2 c3 c4 c6 c12' ).addClass( to );
		} );
	} );
} )( jQuery )
</script>
		<?php
	}

	/**
	 * Sanitize integers
	 *
	 * @since 2.0.0
	 */
	public function sanitize_int( $int ) {
		if ( '' === $int )
			return '';

		return (int) $int;
	}

	/**
	 * Sanitize checkbox options
	 *
	 * @since 1.0.2
	 */
    public function sanitize_checkbox( $value ) {
        if ( 'on' != $value )
            $value = false;

        return $value;
    }
}
$bavotasan_customizer = new Bavotasan_Customizer;

/**
 * Prepare font CSS
 *
 * @param	string $font  The select font
 *
 * @since 1.0.0
 */
function bavotasan_prepare_font( $font ) {
	$font_family = ( 'Lato Light, sans-serif' == $font ) ? 'Lato' : $font;
	$font_family = ( 'Arvo Bold, serif' == $font ) ? 'Arvo' : $font_family;
	$font_weight = ( 'Lato Light, sans-serif' == $font ) ? ' font-weight: 300' : 'font-weight: normal';
	$font_weight = ( 'Lato, sans-serif' == $font || 'Arvo Bold, serif' == $font ) ? ' font-weight: 900' : $font_weight;

	return 'font-family: ' . $font_family . '; ' . $font_weight;
}

if ( ! function_exists( 'bavotasan_websafe_fonts' ) ) :
/**
 * Array of websafe fonts
 *
 * @return	Array of fonts
 *
 * @since 1.0.0
 */
function mp_websafe_fonts() {
    return array(
        'Arial, sans-serif' => 'Arial',
        '"Avant Garde", sans-serif' => 'Avant Garde',
        'Cambria, Georgia, serif' => 'Cambria',
        'Copse, sans-serif' => 'Copse',
        'Garamond, "Hoefler Text", Times New Roman, Times, serif' => 'Garamond',
        'Georgia, serif' => 'Georgia',
        '"Helvetica Neue", Helvetica, sans-serif' => 'Helvetica Neue',
        'Tahoma, Geneva, sans-serif' => 'Tahoma'
    );
}
endif;

if ( ! function_exists( 'bavotasan_google_fonts' ) ) :
/**
 * Array of Google Fonts
 *
 * @return	Array of fonts
 *
 * @since 1.0.0
 */
function bavotasan_google_fonts() {
    return array(
        'Arvo, serif' => 'Arvo *',
        'Arvo Bold, serif' => 'Arvo Bold *',
        'Copse, sans-serif' => 'Copse *',
        'Droid Sans, sans-serif' => 'Droid Sans *',
        'Droid Serif, serif' => 'Droid Serif *',
        'Exo, sans-serif' => 'Exo *',
        'Lato, sans-serif' => 'Lato *',
        'Lato Light, sans-serif' => 'Lato Light *',
        'Lobster, cursive' => 'Lobster *',
        'Nobile, sans-serif' => 'Nobile *',
        'Open Sans, sans-serif' => 'Open Sans *',
        'Oswald, sans-serif' => 'Oswald *',
        'Pacifico, cursive' => 'Pacifico *',
        'Raleway, cursive' => 'Raleway *',
        'Rokkitt, serif' => 'Rokkit *',
        'Russo One, sans-serif' => 'Russo One *',
        'PT Sans, sans-serif' => 'PT Sans *',
        'Quicksand, sans-serif' => 'Quicksand *',
        'Quattrocento, serif' => 'Quattrocento *',
        'Ubuntu, sans-serif' => 'Ubuntu *',
        'Yanone Kaffeesatz, sans-serif' => 'Yanone Kaffeesatz *'
    );
}
endif;